@@ -19,11 +19,12 @@
 #  works or verbatim, obfuscated, compiled or rewritten versions of any
 #  part of this work is illegal and unethical regarding the effort and
 #  time spent here.
-
-from ldict.parameter.base.absfunctionspace import AbstractFunctionSpace
+import operator
+from functools import reduce
+from random import Random
 
 
-class FunctionSpace(AbstractFunctionSpace):
+class FunctionSpace:
     """Aglutination for future application
 
     >>> from ldict import ldict, empty
@@ -32,9 +33,7 @@ class FunctionSpace(AbstractFunctionSpace):
     >>> fs = FunctionSpace() >> empty
     >>> fs >>= {"x": 5}
     >>> fs
-    «{
-        "x": 5
-    }»
+    «{} × {'x': 5}»
     >>> ldict(y=7) >> fs
     {
         "y": 7,
@@ -42,21 +41,39 @@ class FunctionSpace(AbstractFunctionSpace):
     }
     >>> fs >>= ldict(y=7)
     >>> fs
-    «{
-        "x": 5
-    } × {
+    «{} × {'x': 5} × {
         "y": 7
     }»
     >>> fs >>= lambda x,y: {"z": x*y}
     >>> fs
-    «{
-        "x": 5
-    } × {
+    «{} × {'x': 5} × {
         "y": 7
     } × λ»
     """
 
     def __init__(self, *args):
-        from ldict.empty import Empty
-        from ldict.core.ldict_ import Ldict
-        super().__init__(args, dict_type=Ldict, empty_type=Empty)
+        self.functions = args
+
+    def __rrshift__(self, left):
+        return reduce(operator.rshift, (left,) + self.functions)
+
+    def __rshift__(self, other):
+        if isinstance(other, FunctionSpace):
+            return FunctionSpace(*self.functions, *other.functions)
+        return FunctionSpace(*self.functions, other)
+
+    __mul__ = __rshift__
+
+    def __repr__(self):
+        txt = []
+        for f in self.functions:
+            if isinstance(f, list):
+                s = "^"
+            elif isinstance(f, Random):
+                s = "~"
+            elif str(f).startswith("<function "):
+                s = "λ"
+            else:
+                s = str(f)
+            txt.append(s)
+        return "«" + " × ".join(txt) + "»"
